// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "prefab/SceneItemPrefab.hpp"
#include "asset/AssetManager.hpp"
#include "poker/PokerPlayer.hpp"
#include "scene/components/Components.hpp"
#include "visualnovel/components/VisualNovelCharacter.hpp"
#include "display/animation/TiledSpriteAnimation.hpp"
#include "scene/components/display/material/SimpleTexturedMaterial.hpp"

namespace Dawn {
  class DeathPrefab : public SceneItemPrefab<DeathPrefab> {
    public:
      VisualNovelCharacter *vnCharacter;
      AnimationController *animation;

      struct VisualNovelCharacterEmotion emotionDefault;

      static std::vector<Asset*> prefabAssets(AssetManager *assMan) {
        return std::vector<Asset*>{
          assMan->get<TextureAsset>("texture_death"),
          assMan->get<TilesetAsset>("tileset_death"),
          assMan->get<AudioAsset>("audio_test")
        };
      }

      DeathPrefab(Scene *scene, sceneitemid_t id) : SceneItemPrefab(scene, id)
      {

      }

      void prefabInit(AssetManager *man) override {
        auto textureAsset = man->get<TextureAsset>("texture_death");
        auto tilesetAsset = man->get<TilesetAsset>("tileset_death");
        auto audioAsset = man->get<AudioAsset>("audio_test");

        // Emotions
        this->emotionDefault.talkSound = audioAsset;

        auto meshRenderer = this->addComponent<MeshRenderer>();
        auto meshHost = this->addComponent<MeshHost>();

        auto material = this->addComponent<SimpleTexturedMaterial>();
        material->texture = &textureAsset->texture;

        vnCharacter = this->addComponent<VisualNovelCharacter>();
        vnCharacter->nameKey = "character.death.name";

        animation = this->addComponent<AnimationController>();
        
        auto tiledSprite = this->addComponent<TiledSprite>();
        tiledSprite->setTilesetAndSize(&tilesetAsset->tileset);
        tiledSprite->setTile(0);

        this->addComponent<AudioSource>();
        
        this->transform.setLocalPosition(glm::vec3(0, 0, 0)); 
      }
  };
}